.. tin documentation master file, created by
   sphinx-quickstart on Thu Oct 26 17:06:23 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to tin's documentation!
=================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   source/tin.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
